package
Version:
v0.0.0-...-7db0d50
Opens a new window with list of versions in this module.
Published: May 24, 2022
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ResultType struct {
Result string
Retval interface{}
}
Result Type
Source Files
¶
Click to show internal directories.
Click to hide internal directories.